==> gsw-0.0.3.crate: gsw-0.0.3/src/gsw_specvol_coefficients.rs <==
/// ! Specific volume constants

pub const A000: f64 = -1.56497346750e-5;
pub const A001: f64 = 1.85057654290e-5;
pub const A002: f64 = -1.17363867310e-6;
pub const A003: f64 = -3.65270065530e-7;
pub const A004: f64 = 3.14540999020e-7;
pub const A010: f64 = 5.55242129680e-5;
pub const A011: f64 = -2.34332137060e-5;
pub const A012: f64 = 4.26100574800e-6;
pub const A013: f64 = 5.73918103180e-7;
pub const A020: f64 = -4.95634777770e-5;
pub const A021: f64 = 2.37838968519e-5;
pub const A022: f64 = -1.38397620111e-6;
pub const A030: f64 = 2.76445290808e-5;
pub const A031: f64 = -1.36408749928e-5;
pub const A032: f64 = -2.53411666056e-7;
pub const A040: f64 = -4.02698077700e-6;
pub const A041: f64 = 2.53683834070e-6;
pub const A050: f64 = 1.23258565608e-6;
pub const A100: f64 = 3.50095997640e-5;
pub const A101: f64 = -9.56770881560e-6;
pub const A102: f64 = -5.56991545570e-6;
pub const A103: f64 = -2.72956962370e-7;
pub const A110: f64 = -7.48716846880e-5;
pub const A111: f64 = -4.73566167220e-7;
pub const A112: f64 = 7.82747741600e-7;
pub const A120: f64 = 7.24244384490e-5;
pub const A121: f64 = -1.03676320965e-5;
pub const A122: f64 = 2.32856664276e-8;
pub const A130: f64 = -3.50383492616e-5;
pub const A131: f64 = 5.18268711320e-6;
pub const A140: f64 = -1.65263794500e-6;
pub const A200: f64 = -4.35926785610e-5;
pub const A201: f64 = 1.11008347650e-5;
pub const A202: f64 = 5.46207488340e-6;
pub const A210: f64 = 7.18156455200e-5;
pub const A211: f64 = 5.85666925900e-6;
pub const A212: f64 = -1.31462208134e-6;
pub const A220: f64 = -4.30608991440e-5;
pub const A221: f64 = 9.49659182340e-7;
pub const A230: f64 = 1.74814722392e-5;
pub const A300: f64 = 3.45324618280e-5;
pub const A301: f64 = -9.84471178440e-6;
pub const A302: f64 = -1.35441856270e-6;
pub const A310: f64 = -3.73971683740e-5;
pub const A311: f64 = -9.76522784000e-7;
pub const A320: f64 = 6.85899736680e-6;
pub const A400: f64 = -1.19594097880e-5;
pub const A401: f64 = 2.59092252600e-6;
pub const A410: f64 = 7.71906784880e-6;
pub const A500: f64 = 1.38645945810e-6;

pub const B000: f64 = -3.10389819760e-4;
pub const B001: f64 = 2.42624687470e-5;
pub const B002: f64 = -5.84844329840e-7;
pub const B003: f64 = 3.63101885150e-7;
pub const B004: f64 = -1.11471254230e-7;
pub const B010: f64 = 3.50095997640e-5;
pub const B011: f64 = -9.56770881560e-6;
pub const B012: f64 = -5.56991545570e-6;
pub const B013: f64 = -2.72956962370e-7;
pub const B020: f64 = -3.74358423440e-5;
pub const B021: f64 = -2.36783083610e-7;
pub const B022: f64 = 3.91373870800e-7;
pub const B030: f64 = 2.41414794830e-5;
pub const B031: f64 = -3.45587736550e-6;
pub const B032: f64 = 7.76188880920e-9;
pub const B040: f64 = -8.75958731540e-6;
pub const B041: f64 = 1.29567177830e-6;
pub const B050: f64 = -3.30527589000e-7;
pub const B100: f64 = 1.33856134076e-3;
pub const B101: f64 = -6.95849219480e-5;
pub const B102: f64 = -9.62445031940e-6;
pub const B103: f64 = 3.34926075600e-8;
pub const B110: f64 = -8.71853571220e-5;
pub const B111: f64 = 2.22016695300e-5;
pub const B112: f64 = 1.09241497668e-5;
pub const B120: f64 = 7.18156455200e-5;
pub const B121: f64 = 5.85666925900e-6;
pub const B122: f64 = -1.31462208134e-6;
pub const B130: f64 = -2.87072660960e-5;
pub const B131: f64 = 6.33106121560e-7;
pub const B140: f64 = 8.74073611960e-6;
pub const B200: f64 = -2.55143801811e-3;
pub const B201: f64 = 1.12412331915e-4;
pub const B202: f64 = 1.47789320994e-5;
pub const B210: f64 = 1.03597385484e-4;
pub const B211: f64 = -2.95341353532e-5;
pub const B212: f64 = -4.06325568810e-6;
pub const B220: f64 = -5.60957525610e-5;
pub const B221: f64 = -1.46478417600e-6;
pub const B230: f64 = 6.85899736680e-6;
pub const B300: f64 = 2.32344279772e-3;
pub const B301: f64 = -6.92888744480e-5;
pub const B302: f64 = -7.12478989080e-6;
pub const B310: f64 = -4.78376391520e-5;
pub const B311: f64 = 1.03636901040e-5;
pub const B320: f64 = 1.54381356976e-5;
pub const B400: f64 = -1.05461852535e-3;
pub const B401: f64 = 1.54637136265e-5;
pub const B410: f64 = 6.93229729050e-6;
pub const B500: f64 = 1.91594743830e-4;

pub const C000: f64 = -6.0799143809e-5;
pub const C001: f64 = 1.99712338438e-5;
pub const C002: f64 = -3.3928084311e-6;
pub const C003: f64 = 4.2124612320e-7;
pub const C004: f64 = -6.3236306430e-8;
pub const C005: f64 = 1.1768102358e-8;
pub const C010: f64 = 1.8505765429e-5;
pub const C011: f64 = -2.3472773462e-6;
pub const C012: f64 = -1.09581019659e-6;
pub const C013: f64 = 1.25816399608e-6;
pub const C020: f64 = -1.1716606853e-5;
pub const C021: f64 = 4.2610057480e-6;
pub const C022: f64 = 8.6087715477e-7;
pub const C030: f64 = 7.9279656173e-6;
pub const C031: f64 = -9.2265080074e-7;
pub const C040: f64 = -3.4102187482e-6;
pub const C041: f64 = -1.26705833028e-7;
pub const C050: f64 = 5.0736766814e-7;
pub const C100: f64 = 2.4262468747e-5;
pub const C101: f64 = -1.16968865968e-6;
pub const C102: f64 = 1.08930565545e-6;
pub const C103: f64 = -4.4588501692e-7;
pub const C110: f64 = -9.5677088156e-6;
pub const C111: f64 = -1.11398309114e-5;
pub const C112: f64 = -8.1887088711e-7;
pub const C120: f64 = -2.3678308361e-7;
pub const C121: f64 = 7.8274774160e-7;
pub const C130: f64 = -3.4558773655e-6;
pub const C131: f64 = 1.55237776184e-8;
pub const C140: f64 = 1.2956717783e-6;
pub const C200: f64 = -3.4792460974e-5;
pub const C201: f64 = -9.6244503194e-6;
pub const C202: f64 = 5.0238911340e-8;
pub const C210: f64 = 1.1100834765e-5;
pub const C211: f64 = 1.09241497668e-5;
pub const C220: f64 = 2.9283346295e-6;
pub const C221: f64 = -1.31462208134e-6;
pub const C230: f64 = 3.1655306078e-7;
pub const C300: f64 = 3.7470777305e-5;
pub const C301: f64 = 9.8526213996e-6;
pub const C310: f64 = -9.8447117844e-6;
pub const C311: f64 = -2.7088371254e-6;
pub const C320: f64 = -4.8826139200e-7;
pub const C400: f64 = -1.7322218612e-5;
pub const C401: f64 = -3.5623949454e-6;
pub const C410: f64 = 2.5909225260e-6;
pub const C500: f64 = 3.0927427253e-6;

pub const V000: f64 = 1.0769995862e-3;
pub const V001: f64 = -6.0799143809e-5;
pub const V002: f64 = 9.9856169219e-6;
pub const V003: f64 = -1.1309361437e-6;
pub const V004: f64 = 1.0531153080e-7;
pub const V005: f64 = -1.2647261286e-8;
pub const V006: f64 = 1.9613503930e-9;
pub const V010: f64 = -1.5649734675e-5;
pub const V011: f64 = 1.8505765429e-5;
pub const V012: f64 = -1.1736386731e-6;
pub const V013: f64 = -3.6527006553e-7;
pub const V014: f64 = 3.1454099902e-7;
pub const V020: f64 = 2.7762106484e-5;
pub const V021: f64 = -1.1716606853e-5;
pub const V022: f64 = 2.1305028740e-6;
pub const V023: f64 = 2.8695905159e-7;
pub const V030: f64 = -1.6521159259e-5;
pub const V031: f64 = 7.9279656173e-6;
pub const V032: f64 = -4.6132540037e-7;
pub const V040: f64 = 6.9111322702e-6;
pub const V041: f64 = -3.4102187482e-6;
pub const V042: f64 = -6.3352916514e-8;
pub const V050: f64 = -8.0539615540e-7;
pub const V051: f64 = 5.0736766814e-7;
pub const V060: f64 = 2.0543094268e-7;
pub const V100: f64 = -3.1038981976e-4;
pub const V101: f64 = 2.4262468747e-5;
pub const V102: f64 = -5.8484432984e-7;
pub const V103: f64 = 3.6310188515e-7;
pub const V104: f64 = -1.1147125423e-7;
pub const V110: f64 = 3.5009599764e-5;
pub const V111: f64 = -9.5677088156e-6;
pub const V112: f64 = -5.5699154557e-6;
pub const V113: f64 = -2.7295696237e-7;
pub const V120: f64 = -3.7435842344e-5;
pub const V121: f64 = -2.3678308361e-7;
pub const V122: f64 = 3.9137387080e-7;
pub const V130: f64 = 2.4141479483e-5;
pub const V131: f64 = -3.4558773655e-6;
pub const V132: f64 = 7.7618888092e-9;
pub const V140: f64 = -8.7595873154e-6;
pub const V141: f64 = 1.2956717783e-6;
pub const V150: f64 = -3.3052758900e-7;
pub const V200: f64 = 6.6928067038e-4;
pub const V201: f64 = -3.4792460974e-5;
pub const V202: f64 = -4.8122251597e-6;
pub const V203: f64 = 1.6746303780e-8;
pub const V210: f64 = -4.3592678561e-5;
pub const V211: f64 = 1.1100834765e-5;
pub const V212: f64 = 5.4620748834e-6;
pub const V220: f64 = 3.5907822760e-5;
pub const V221: f64 = 2.9283346295e-6;
pub const V222: f64 = -6.5731104067e-7;
pub const V230: f64 = -1.4353633048e-5;
pub const V231: f64 = 3.1655306078e-7;
pub const V240: f64 = 4.3703680598e-6;
pub const V300: f64 = -8.5047933937e-4;
pub const V301: f64 = 3.7470777305e-5;
pub const V302: f64 = 4.9263106998e-6;
pub const V310: f64 = 3.4532461828e-5;
pub const V311: f64 = -9.8447117844e-6;
pub const V312: f64 = -1.3544185627e-6;
pub const V320: f64 = -1.8698584187e-5;
pub const V321: f64 = -4.8826139200e-7;
pub const V330: f64 = 2.2863324556e-6;
pub const V400: f64 = 5.8086069943e-4;
pub const V401: f64 = -1.7322218612e-5;
pub const V402: f64 = -1.7811974727e-6;
pub const V410: f64 = -1.1959409788e-5;
pub const V411: f64 = 2.5909225260e-6;
pub const V420: f64 = 3.8595339244e-6;
pub const V500: f64 = -2.1092370507e-4;
pub const V501: f64 = 3.0927427253e-6;
pub const V510: f64 = 1.3864594581e-6;
pub const V600: f64 = 3.1932457305e-5;

==> gsw-0.0.9.crate: gsw-0.0.9/src/gsw_specvol_coefficients.rs <==
/// ! Specific volume constants

pub const A000: f64 = -1.56497346750e-5;
pub const A001: f64 = 1.85057654290e-5;
pub const A002: f64 = -1.17363867310e-6;
pub const A003: f64 = -3.65270065530e-7;
pub const A004: f64 = 3.14540999020e-7;
pub const A010: f64 = 5.55242129680e-5;
pub const A011: f64 = -2.34332137060e-5;
pub const A012: f64 = 4.26100574800e-6;
pub const A013: f64 = 5.73918103180e-7;
pub const A020: f64 = -4.95634777770e-5;
pub const A021: f64 = 2.37838968519e-5;
pub const A022: f64 = -1.38397620111e-6;
pub const A030: f64 = 2.76445290808e-5;
pub const A031: f64 = -1.36408749928e-5;
pub const A032: f64 = -2.53411666056e-7;
pub const A040: f64 = -4.02698077700e-6;
pub const A041: f64 = 2.53683834070e-6;
pub const A050: f64 = 1.23258565608e-6;
pub const A100: f64 = 3.50095997640e-5;
pub const A101: f64 = -9.56770881560e-6;
pub const A102: f64 = -5.56991545570e-6;
pub const A103: f64 = -2.72956962370e-7;
pub const A110: f64 = -7.48716846880e-5;
pub const A111: f64 = -4.73566167220e-7;
pub const A112: f64 = 7.82747741600e-7;
pub const A120: f64 = 7.24244384490e-5;
pub const A121: f64 = -1.03676320965e-5;
pub const A122: f64 = 2.32856664276e-8;
pub const A130: f64 = -3.50383492616e-5;
pub const A131: f64 = 5.18268711320e-6;
pub const A140: f64 = -1.65263794500e-6;
pub const A200: f64 = -4.35926785610e-5;
pub const A201: f64 = 1.11008347650e-5;
pub const A202: f64 = 5.46207488340e-6;
pub const A210: f64 = 7.18156455200e-5;
pub const A211: f64 = 5.85666925900e-6;
pub const A212: f64 = -1.31462208134e-6;
pub const A220: f64 = -4.30608991440e-5;
pub const A221: f64 = 9.49659182340e-7;
pub const A230: f64 = 1.74814722392e-5;
pub const A300: f64 = 3.45324618280e-5;
pub const A301: f64 = -9.84471178440e-6;
pub const A302: f64 = -1.35441856270e-6;
pub const A310: f64 = -3.73971683740e-5;
pub const A311: f64 = -9.76522784000e-7;
pub const A320: f64 = 6.85899736680e-6;
pub const A400: f64 = -1.19594097880e-5;
pub const A401: f64 = 2.59092252600e-6;
pub const A410: f64 = 7.71906784880e-6;
pub const A500: f64 = 1.38645945810e-6;

pub const B000: f64 = -3.10389819760e-4;
pub const B001: f64 = 2.42624687470e-5;
pub const B002: f64 = -5.84844329840e-7;
pub const B003: f64 = 3.63101885150e-7;
pub const B004: f64 = -1.11471254230e-7;
pub const B010: f64 = 3.50095997640e-5;
pub const B011: f64 = -9.56770881560e-6;
pub const B012: f64 = -5.56991545570e-6;
pub const B013: f64 = -2.72956962370e-7;
pub const B020: f64 = -3.74358423440e-5;
pub const B021: f64 = -2.36783083610e-7;
pub const B022: f64 = 3.91373870800e-7;
pub const B030: f64 = 2.41414794830e-5;
pub const B031: f64 = -3.45587736550e-6;
pub const B032: f64 = 7.76188880920e-9;
pub const B040: f64 = -8.75958731540e-6;
pub const B041: f64 = 1.29567177830e-6;
pub const B050: f64 = -3.30527589000e-7;
pub const B100: f64 = 1.33856134076e-3;
pub const B101: f64 = -6.95849219480e-5;
pub const B102: f64 = -9.62445031940e-6;
pub const B103: f64 = 3.34926075600e-8;
pub const B110: f64 = -8.71853571220e-5;
pub const B111: f64 = 2.22016695300e-5;
pub const B112: f64 = 1.09241497668e-5;
pub const B120: f64 = 7.18156455200e-5;
pub const B121: f64 = 5.85666925900e-6;
pub const B122: f64 = -1.31462208134e-6;
pub const B130: f64 = -2.87072660960e-5;
pub const B131: f64 = 6.33106121560e-7;
pub const B140: f64 = 8.74073611960e-6;
pub const B200: f64 = -2.55143801811e-3;
pub const B201: f64 = 1.12412331915e-4;
pub const B202: f64 = 1.47789320994e-5;
pub const B210: f64 = 1.03597385484e-4;
pub const B211: f64 = -2.95341353532e-5;
pub const B212: f64 = -4.06325568810e-6;
pub const B220: f64 = -5.60957525610e-5;
pub const B221: f64 = -1.46478417600e-6;
pub const B230: f64 = 6.85899736680e-6;
pub const B300: f64 = 2.32344279772e-3;
pub const B301: f64 = -6.92888744480e-5;
pub const B302: f64 = -7.12478989080e-6;
pub const B310: f64 = -4.78376391520e-5;
pub const B311: f64 = 1.03636901040e-5;
pub const B320: f64 = 1.54381356976e-5;
pub const B400: f64 = -1.05461852535e-3;
pub const B401: f64 = 1.54637136265e-5;
pub const B410: f64 = 6.93229729050e-6;
pub const B500: f64 = 1.91594743830e-4;

pub const C000: f64 = -6.0799143809e-5;
pub const C001: f64 = 1.99712338438e-5;
pub const C002: f64 = -3.3928084311e-6;
pub const C003: f64 = 4.2124612320e-7;
pub const C004: f64 = -6.3236306430e-8;
pub const C005: f64 = 1.1768102358e-8;
pub const C010: f64 = 1.8505765429e-5;
pub const C011: f64 = -2.3472773462e-6;
pub const C012: f64 = -1.09581019659e-6;
pub const C013: f64 = 1.25816399608e-6;
pub const C020: f64 = -1.1716606853e-5;
pub const C021: f64 = 4.2610057480e-6;
pub const C022: f64 = 8.6087715477e-7;
pub const C030: f64 = 7.9279656173e-6;
pub const C031: f64 = -9.2265080074e-7;
pub const C040: f64 = -3.4102187482e-6;
pub const C041: f64 = -1.26705833028e-7;
pub const C050: f64 = 5.0736766814e-7;
pub const C100: f64 = 2.4262468747e-5;
pub const C101: f64 = -1.16968865968e-6;
pub const C102: f64 = 1.08930565545e-6;
pub const C103: f64 = -4.4588501692e-7;
pub const C110: f64 = -9.5677088156e-6;
pub const C111: f64 = -1.11398309114e-5;
pub const C112: f64 = -8.1887088711e-7;
pub const C120: f64 = -2.3678308361e-7;
pub const C121: f64 = 7.8274774160e-7;
pub const C130: f64 = -3.4558773655e-6;
pub const C131: f64 = 1.55237776184e-8;
pub const C140: f64 = 1.2956717783e-6;
pub const C200: f64 = -3.4792460974e-5;
pub const C201: f64 = -9.6244503194e-6;
pub const C202: f64 = 5.0238911340e-8;
pub const C210: f64 = 1.1100834765e-5;
pub const C211: f64 = 1.09241497668e-5;
pub const C220: f64 = 2.9283346295e-6;
pub const C221: f64 = -1.31462208134e-6;
pub const C230: f64 = 3.1655306078e-7;
pub const C300: f64 = 3.7470777305e-5;
pub const C301: f64 = 9.8526213996e-6;
pub const C310: f64 = -9.8447117844e-6;
pub const C311: f64 = -2.7088371254e-6;
pub const C320: f64 = -4.8826139200e-7;
pub const C400: f64 = -1.7322218612e-5;
pub const C401: f64 = -3.5623949454e-6;
pub const C410: f64 = 2.5909225260e-6;
pub const C500: f64 = 3.0927427253e-6;

pub const H001: f64 = 1.07699958620e-3;
pub const H002: f64 = -3.03995719050e-5;
pub const H003: f64 = 3.32853897400e-6;
pub const H004: f64 = -2.82734035930e-7;
pub const H005: f64 = 2.10623061600e-8;
pub const H006: f64 = -2.10787688100e-9;
pub const H007: f64 = 2.80192913290e-10;
pub const H011: f64 = -1.56497346750e-5;
pub const H012: f64 = 9.25288271450e-6;
pub const H013: f64 = -3.91212891030e-7;
pub const H014: f64 = -9.13175163830e-8;
pub const H015: f64 = 6.29081998040e-8;
pub const H021: f64 = 2.77621064840e-5;
pub const H022: f64 = -5.85830342650e-6;
pub const H023: f64 = 7.10167624670e-7;
pub const H024: f64 = 7.17397628980e-8;
pub const H031: f64 = -1.65211592590e-5;
pub const H032: f64 = 3.96398280870e-6;
pub const H033: f64 = -1.53775133460e-7;
pub const H042: f64 = -1.70510937410e-6;
pub const H043: f64 = -2.11176388380e-8;
pub const H041: f64 = 6.91113227020e-6;
pub const H051: f64 = -8.05396155400e-7;
pub const H052: f64 = 2.53683834070e-7;
pub const H061: f64 = 2.05430942680e-7;
pub const H101: f64 = -3.10389819760e-4;
pub const H102: f64 = 1.21312343735e-5;
pub const H103: f64 = -1.94948109950e-7;
pub const H104: f64 = 9.07754712880e-8;
pub const H105: f64 = -2.22942508460e-8;
pub const H111: f64 = 3.50095997640e-5;
pub const H112: f64 = -4.78385440780e-6;
pub const H113: f64 = -1.85663848520e-6;
pub const H114: f64 = -6.82392405930e-8;
pub const H121: f64 = -3.74358423440e-5;
pub const H122: f64 = -1.18391541805e-7;
pub const H123: f64 = 1.30457956930e-7;
pub const H131: f64 = 2.41414794830e-5;
pub const H132: f64 = -1.72793868275e-6;
pub const H133: f64 = 2.58729626970e-9;
pub const H141: f64 = -8.75958731540e-6;
pub const H142: f64 = 6.47835889150e-7;
pub const H151: f64 = -3.30527589000e-7;
pub const H201: f64 = 6.69280670380e-4;
pub const H202: f64 = -1.73962304870e-5;
pub const H203: f64 = -1.60407505320e-6;
pub const H204: f64 = 4.18657594500e-9;
pub const H211: f64 = -4.35926785610e-5;
pub const H212: f64 = 5.55041738250e-6;
pub const H213: f64 = 1.82069162780e-6;
pub const H221: f64 = 3.59078227600e-5;
pub const H222: f64 = 1.46416731475e-6;
pub const H223: f64 = -2.19103680220e-7;
pub const H231: f64 = -1.43536330480e-5;
pub const H232: f64 = 1.58276530390e-7;
pub const H241: f64 = 4.37036805980e-6;
pub const H301: f64 = -8.50479339370e-4;
pub const H302: f64 = 1.87353886525e-5;
pub const H303: f64 = 1.64210356660e-6;
pub const H311: f64 = 3.45324618280e-5;
pub const H312: f64 = -4.92235589220e-6;
pub const H313: f64 = -4.51472854230e-7;
pub const H321: f64 = -1.86985841870e-5;
pub const H322: f64 = -2.44130696000e-7;
pub const H331: f64 = 2.28633245560e-6;
pub const H401: f64 = 5.80860699430e-4;
pub const H402: f64 = -8.66110930600e-6;
pub const H403: f64 = -5.93732490900e-7;
pub const H411: f64 = -1.19594097880e-5;
pub const H421: f64 = 3.85953392440e-6;
pub const H412: f64 = 1.29546126300e-6;
pub const H501: f64 = -2.10923705070e-4;
pub const H502: f64 = 1.54637136265e-6;
pub const H511: f64 = 1.38645945810e-6;
pub const H601: f64 = 3.19324573050e-5;

pub const V000: f64 = 1.0769995862e-3;
pub const V001: f64 = -6.0799143809e-5;
pub const V002: f64 = 9.9856169219e-6;
pub const V003: f64 = -1.1309361437e-6;
pub const V004: f64 = 1.0531153080e-7;
pub const V005: f64 = -1.2647261286e-8;
pub const V006: f64 = 1.9613503930e-9;
pub const V010: f64 = -1.5649734675e-5;
pub const V011: f64 = 1.8505765429e-5;
pub const V012: f64 = -1.1736386731e-6;
pub const V013: f64 = -3.6527006553e-7;
pub const V014: f64 = 3.1454099902e-7;
pub const V020: f64 = 2.7762106484e-5;
pub const V021: f64 = -1.1716606853e-5;
pub const V022: f64 = 2.1305028740e-6;
pub const V023: f64 = 2.8695905159e-7;
pub const V030: f64 = -1.6521159259e-5;
pub const V031: f64 = 7.9279656173e-6;
pub const V032: f64 = -4.6132540037e-7;
pub const V040: f64 = 6.9111322702e-6;
pub const V041: f64 = -3.4102187482e-6;
pub const V042: f64 = -6.3352916514e-8;
pub const V050: f64 = -8.0539615540e-7;
pub const V051: f64 = 5.0736766814e-7;
pub const V060: f64 = 2.0543094268e-7;
pub const V100: f64 = -3.1038981976e-4;
pub const V101: f64 = 2.4262468747e-5;
pub const V102: f64 = -5.8484432984e-7;
pub const V103: f64 = 3.6310188515e-7;
pub const V104: f64 = -1.1147125423e-7;
pub const V110: f64 = 3.5009599764e-5;
pub const V111: f64 = -9.5677088156e-6;
pub const V112: f64 = -5.5699154557e-6;
pub const V113: f64 = -2.7295696237e-7;
pub const V120: f64 = -3.7435842344e-5;
pub const V121: f64 = -2.3678308361e-7;
pub const V122: f64 = 3.9137387080e-7;
pub const V130: f64 = 2.4141479483e-5;
pub const V131: f64 = -3.4558773655e-6;
pub const V132: f64 = 7.7618888092e-9;
pub const V140: f64 = -8.7595873154e-6;
pub const V141: f64 = 1.2956717783e-6;
pub const V150: f64 = -3.3052758900e-7;
pub const V200: f64 = 6.6928067038e-4;
pub const V201: f64 = -3.4792460974e-5;
pub const V202: f64 = -4.8122251597e-6;
pub const V203: f64 = 1.6746303780e-8;
pub const V210: f64 = -4.3592678561e-5;
pub const V211: f64 = 1.1100834765e-5;
pub const V212: f64 = 5.4620748834e-6;
pub const V220: f64 = 3.5907822760e-5;
pub const V221: f64 = 2.9283346295e-6;
pub const V222: f64 = -6.5731104067e-7;
pub const V230: f64 = -1.4353633048e-5;
pub const V231: f64 = 3.1655306078e-7;
pub const V240: f64 = 4.3703680598e-6;
pub const V300: f64 = -8.5047933937e-4;
pub const V301: f64 = 3.7470777305e-5;
pub const V302: f64 = 4.9263106998e-6;
pub const V310: f64 = 3.4532461828e-5;
pub const V311: f64 = -9.8447117844e-6;
pub const V312: f64 = -1.3544185627e-6;
pub const V320: f64 = -1.8698584187e-5;
pub const V321: f64 = -4.8826139200e-7;
pub const V330: f64 = 2.2863324556e-6;
pub const V400: f64 = 5.8086069943e-4;
pub const V401: f64 = -1.7322218612e-5;
pub const V402: f64 = -1.7811974727e-6;
pub const V410: f64 = -1.1959409788e-5;
pub const V411: f64 = 2.5909225260e-6;
pub const V420: f64 = 3.8595339244e-6;
pub const V500: f64 = -2.1092370507e-4;
pub const V501: f64 = 3.0927427253e-6;
pub const V510: f64 = 1.3864594581e-6;
pub const V600: f64 = 3.1932457305e-5;
